# Generated by Django 4.1.2 on 2022-10-26 08:51

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Utenza',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('CF', models.CharField(max_length=200)),
                ('Nome', models.CharField(max_length=200)),
                ('Cognome', models.CharField(max_length=200)),
                ('DataNascita', models.DateTimeField()),
            ],
        ),
    ]
