# Generated by Django 4.1.2 on 2022-10-26 09:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('miaApplicazione', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='utenza',
            name='DataNascita',
            field=models.DateField(),
        ),
    ]
