from setuptools import setup, find_packages

setup(
    name="mioProgetto",
    version="0.4",
    description="mioProgetto",
    long_description="mioProgetto",
    long_description_content_type='text/x-rst',
    url="https://gitlab.com/magni5/2022_assignment1_itis.git",
    author="Gruppo ITIS",
    packages=find_packages(),
    python_requires='>=3',
)
